==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/KernelChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KernelChaosStatusFluent<A extends KernelChaosStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,ChaosCondition item);
  public A setToConditions(Integer index,ChaosCondition item);
  public A addToConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A addAllToConditions(Collection<ChaosCondition> items);
  public A removeFromConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A removeAllFromConditions(Collection<ChaosCondition> items);
  public A removeMatchingFromConditions(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ChaosCondition> getConditions();
  public List<ChaosCondition> buildConditions();
  public ChaosCondition buildCondition(Integer index);
  public ChaosCondition buildFirstCondition();
  public ChaosCondition buildLastCondition();
  public ChaosCondition buildMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public A withConditions(List<ChaosCondition> conditions);
  public A withConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String reason,String status,String type);
  public KernelChaosStatusFluent.ConditionsNested<A> addNewCondition();
  public KernelChaosStatusFluent.ConditionsNested<A> addNewConditionLike(ChaosCondition item);
  public KernelChaosStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,ChaosCondition item);
  public KernelChaosStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public KernelChaosStatusFluent.ConditionsNested<A> editFirstCondition();
  public KernelChaosStatusFluent.ConditionsNested<A> editLastCondition();
  public KernelChaosStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExperiment instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExperimentStatus getExperiment();
  public ExperimentStatus buildExperiment();
  public A withExperiment(ExperimentStatus experiment);
  public Boolean hasExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> withNewExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
  public KernelChaosStatusFluent.ExperimentNested<A> editExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
  public interface ConditionsNested<N> extends Nested<N>,ChaosConditionFluent<KernelChaosStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ExperimentNested<N> extends Nested<N>,ExperimentStatusFluent<KernelChaosStatusFluent.ExperimentNested<N>>{
    public N and();
    public N endExperiment();
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/KernelChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KernelChaosStatusFluent<A extends KernelChaosStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,ChaosCondition item);
  public A setToConditions(int index,ChaosCondition item);
  public A addToConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A addAllToConditions(Collection<ChaosCondition> items);
  public A removeFromConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A removeAllFromConditions(Collection<ChaosCondition> items);
  public A removeMatchingFromConditions(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ChaosCondition> getConditions();
  public List<ChaosCondition> buildConditions();
  public ChaosCondition buildCondition(int index);
  public ChaosCondition buildFirstCondition();
  public ChaosCondition buildLastCondition();
  public ChaosCondition buildMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public A withConditions(List<ChaosCondition> conditions);
  public A withConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String reason,String status,String type);
  public KernelChaosStatusFluent.ConditionsNested<A> addNewCondition();
  public KernelChaosStatusFluent.ConditionsNested<A> addNewConditionLike(ChaosCondition item);
  public KernelChaosStatusFluent.ConditionsNested<A> setNewConditionLike(int index,ChaosCondition item);
  public KernelChaosStatusFluent.ConditionsNested<A> editCondition(int index);
  public KernelChaosStatusFluent.ConditionsNested<A> editFirstCondition();
  public KernelChaosStatusFluent.ConditionsNested<A> editLastCondition();
  public KernelChaosStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExperiment instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExperimentStatus getExperiment();
  public ExperimentStatus buildExperiment();
  public A withExperiment(ExperimentStatus experiment);
  public Boolean hasExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> withNewExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
  public KernelChaosStatusFluent.ExperimentNested<A> editExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
  public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
  public interface ConditionsNested<N> extends Nested<N>,ChaosConditionFluent<KernelChaosStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ExperimentNested<N> extends Nested<N>,ExperimentStatusFluent<KernelChaosStatusFluent.ExperimentNested<N>>{
    public N and();
    public N endExperiment();
    
  }
  
}
